# Changelog

<!--next-version-placeholder-->

## v0.7.0 (2023-02-08)
### Feature
* Added two additional intensifers for Danish ([`21f121d`](https://github.com/KennethEnevoldsen/asent/commit/21f121dafc406a2fb6e357b06fdac70a8d6f5f40))
* Added two additional intensifiers for Danish ([`9a6351b`](https://github.com/KennethEnevoldsen/asent/commit/9a6351bee4b2a8c5f59991fe5439307b84f731bd))

### Fix
* Update prediciton visualiser handle overlapping spans ([`f68bb55`](https://github.com/KennethEnevoldsen/asent/commit/f68bb55206aa54a74147fd1734c941a2a140d653))
* Sentence bounderies are now considered when check negations and intensifiers ([`4caa5a1`](https://github.com/KennethEnevoldsen/asent/commit/4caa5a1977fdea6f465e94a2fe52b1fdd51aa338))

### Documentation
* Update python req. badge ([`01e8cb6`](https://github.com/KennethEnevoldsen/asent/commit/01e8cb61a863732186c53b8b464bc1b1a5dbf149))
* Fixed version for tutorial req. ([`5e0a75b`](https://github.com/KennethEnevoldsen/asent/commit/5e0a75b0700572fb9fc63658ca7e0be2cebc8e8f))
* Fixed error in tutorials req. ([`da69d28`](https://github.com/KennethEnevoldsen/asent/commit/da69d283fdabe2635a4e8d4b1f1a59f62713d5c9))
* Updated documentation ([`52b6380`](https://github.com/KennethEnevoldsen/asent/commit/52b63809ff56dc376c8f74f518600170e698afac))
* Updated docs with new changes ([`11b21ce`](https://github.com/KennethEnevoldsen/asent/commit/11b21cefed4e3e0522e689ecd239524683f0a6f2))
* Updated documentation ([`219a29f`](https://github.com/KennethEnevoldsen/asent/commit/219a29f814a1e0283f1022b2bee941ceba0f0d76))
* Updated example in readme ([`65a9de9`](https://github.com/KennethEnevoldsen/asent/commit/65a9de9023e7055b9a045e2e6de211000a217c7f))
